GenUiControllerState class final

Annotations

Constructors

GenUiControllerState({GenUiStatus status = GenUiStatus.idle, GenUiDocument? activeDocument, GenUiDocument? lastSuccessfulDocument, String? lastPrompt, String? errorMessage, String? rawPayload, GenUiDiagnostics diagnostics = const GenUiDiagnostics()})
const

Properties

activeDocument → GenUiDocument?
final
diagnostics → GenUiDiagnostics
final
errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
lastPrompt → String?
final
lastSuccessfulDocument → GenUiDocument?
final
rawPayload → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → GenUiStatus
final

Methods

copyWith({GenUiStatus? status, GenUiDocument? activeDocument, bool clearActiveDocument = false, GenUiDocument? lastSuccessfulDocument, bool clearLastSuccessfulDocument = false, String? lastPrompt, bool clearLastPrompt = false, String? errorMessage, bool clearErrorMessage = false, String? rawPayload, bool clearRawPayload = false, GenUiDiagnostics? diagnostics}) → GenUiControllerState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited