GenUiRenderer class final
Constructors
- GenUiRenderer({GenUiWidgetRegistry? registry})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- registry → GenUiWidgetRegistry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildDocument(
BuildContext context, GenUiDocument document) → Widget -
buildNode(
BuildContext context, GenUiNode node) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited