GenUiActionRegistry class final
- Implemented types
Constructors
-
GenUiActionRegistry({Map<
String, GenUiActionHandler> handlers = const {}, GenUiActionHandler? onUnhandled})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onUnhandled → GenUiActionHandler?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispatch(
GenUiActionRequest request) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited