GenUiDiagnostics class final

Annotations

Constructors

GenUiDiagnostics({List<String> warnings = const <String>[], List<String> appliedMigrations = const <String>[]})
const

Properties

appliedMigrations List<String>
final
hashCode int
The hash code for this object.
no setterinherited
hasWarnings bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited